==> familia_0.1.tar.gz: familia/src/window.h <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#ifndef _WINDOW_H
#define _WINDOW_H

#include <gtkmm.h>
#include <glibmm/ustring.h>
#include <vector>

//#include "tabs.h"
#include "drawingarea.h"
#include "file/file.h"

class Window : public Gtk::Window {
public:
  typedef Glib::ustring _String;

  Window();
  virtual ~Window();

protected:
  //Signal handlers:
  void on_menu_file_new();
  void on_menu_file_open();
  void on_menu_file_quit();
  //Member widgets:

  //Child widgets:
  Gtk::Box vbox;
  //  Tabs tabs;
  DrawingArea area;

  Glib::RefPtr<Gtk::UIManager> m_refUIManager;
  Glib::RefPtr<Gtk::ActionGroup> m_refActionGroup;
    
  void open_file(Glib::ustring filename);
};

#endif // WINDOW_H

==> familia_0.1.2.tar.gz: familia/src/window.h <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#ifndef _WINDOW_H
#define _WINDOW_H

#include <gtkmm.h>

class Window : public Gtk::ApplicationWindow {
public:
  Window(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>&
	 builder);
  virtual ~Window();

  void on_menu_file_open();
  void on_menu_file_close();
protected:
  Glib::RefPtr<Gtk::UIManager> m_refUIManager;
  Glib::RefPtr<Gtk::ActionGroup> m_refActionGroup;
  Glib::RefPtr<Gtk::Builder> m_refBuilder;
};

#endif // WINDOW_H
